module.exports = defineTest({
	description: 'simplifies logical expressions that resolve statically to non-boolean values'
});
